@@ -3,7 +3,7 @@ package Protocol::DBus;
 use strict;
 use warnings;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 =encoding utf8
 
@@ -51,9 +51,11 @@ Example:
 
     my $loop = IO::Async::Loop->new();
 
-    Protcol::DBus::Client::IOAsync::login_session($loop)->then(
+    my $dbus = Protcol::DBus::Client::IOAsync::login_session($loop);
+
+    $dbus->initialize()->then(
         sub ($dbus) {
-            $dbus->send_call( … );  # same arguments as above
+            return $dbus->send_call( … );  # same arguments as above
         },
     )->finally( sub { $loop->stop() } );
 
